@@ -58,7 +58,7 @@ co.x <- cbind(rep(1,ncontrols),co.x)
     }
 
 
-tr.total <- apply(X[Treatment==1,],2,sum)
+tr.total <- apply(as.matrix(X[Treatment==1,]),2,sum)
 
     if (is.null(norm.constant)) {
         norm.constant <- ntreated
